@@ -516,7 +516,7 @@ impl DkgCommand {
             } => {
                 let variant = Variant::DkgMessage { dkg_key, message };
                 let message =
-                    RoutingMsg::single_src(node, DstLocation::DirectAndUnrouted, variant, None)?;
+                    RoutingMsg::single_src(node, DstLocation::DirectAndUnrouted, variant, key)?;
 
                 Ok(Command::send_message_to_nodes(
                     recipients.clone(),
@@ -550,7 +550,7 @@ impl DkgCommand {
                     non_participants,
                 };
                 let message =
-                    RoutingMsg::single_src(node, DstLocation::DirectAndUnrouted, variant, None)?;
+                    RoutingMsg::single_src(node, DstLocation::DirectAndUnrouted, variant, key)?;
 
                 Ok(Command::send_message_to_nodes(
                     recipients.clone(),
